@@ -98,7 +98,7 @@ import.spc <- function(file, text = NULL){
 
   if (is.null(text)){
     stopifnot(file.exists(file))
-    text <- readLines(file)
+    text <- readLines(file, warn = FALSE)
   } else {
     stopifnot(inherits(text, "character"))
     text <- paste(text, collapse = "\n")
@@ -178,6 +178,10 @@ print.import.spc <- function(x, ...){
 
 ext_ser_call <- function(spc, vname){
   if (is.null(spc)) return(NULL)
+  
+  # the default data format for X-13 is "free"
+  fformat <- ifelse(is.null(spc$format), "free", spc$format)
+  frm <- rem_quotes(fformat)
 
   # analyze series spec
   if ("data" %in% names(spc)){
@@ -190,9 +194,7 @@ ext_ser_call <- function(spc, vname){
                 ", start = ", deparse(start), ", frequency = ", f, ")")
 
   } else if ("file" %in% names(spc)){
-
-    frm <- rem_quotes(spc$format)
-
+    
     # fragment for name, for fortran and x11 series
     if (!is.null(spc$name)) {
       nm <- rem_quotes(spc$name)
@@ -359,7 +361,7 @@ import.ts <- function(file,
 
 
   if (format %in% c("datevalue", "datevaluecomma", "free", "freecomma")){
-    txt <- readLines(file)
+    txt <- readLines(file, warn = FALSE)
 
     dec <- if (format %in% c("datevaluecomma", "freecomma")) "," else "."
     sep <- if (grepl("\\t", txt[2])) "\t" else " "
@@ -495,7 +497,7 @@ import_fortran <- function(file, format, frequency, start = NULL, name = NULL){
 
 
 import_tramo <- function(file){
-  txt <- readLines(file)
+  txt <- readLines(file, warn = FALSE)
   ssp <- strsplit(gsub("^ +| +$", "", txt[2]), " ")[[1]]
   if (length(ssp) != 4){
     stop("tramo format: line 2 must have 4 elements.")
