@@ -1,27 +1,35 @@
 read_est <- function(file){
   # read and parse a .est file
-  # 
+  #
   # file  full path without file ending
   #
   # return a list with coefficients, standard errors and some statistics
-  
-  est <-  readLines(paste0(file, ".est"))
+
+  estfile <- paste0(file, ".est")
+
+  # For short-ish series no est file is written
+  # see issue #296
+  if(!file.exists(estfile)) {
+    return(NULL)
+  }
+
+  est <-  readLines(estfile)
   if (length(est) == 0){
     return(NULL)
   }
-  
+
   # lines on which a section (or subsection) starts
   dollars <- grep("\\$", est)
 
   z <- list()
-  
+
   # regression section
   reg.start <- grep("\\$regression\\$estimates", est)
   if (length(reg.start) > 0){
     reg.end <- dollars[which(dollars==reg.start) + 1] - 1
-    z$reg <- read.table(text = est[(reg.start + 1):reg.end], sep = "\t", 
+    z$reg <- read.table(text = est[(reg.start + 1):reg.end], sep = "\t",
                         header = TRUE, stringsAsFactors = FALSE)[-1,]
-    
+
     reg.names <- z$reg$variable
     reg.coef <- as.numeric(z$reg$estimate)
     if (is.null(z$reg$standard.error)){
@@ -35,15 +43,15 @@ read_est <- function(file){
     reg.coef <- NULL
     reg.se <- NULL
   }
-  
+
   # arima section
   arima.start <- grep("\\$arima\\$estimates", est)
   if (length(arima.start) > 0){
     arima.end <- dollars[which(dollars==arima.start) + 1] - 1
-    z$arima <- read.table(text = est[(arima.start + 1):arima.end], sep = "\t", 
+    z$arima <- read.table(text = est[(arima.start + 1):arima.end], sep = "\t",
                           header = TRUE, stringsAsFactors = FALSE)[-1,]
 
-    arima.names <- paste(z$arima$operator, z$arima$factor, 
+    arima.names <- paste(z$arima$operator, z$arima$factor,
                                 z$arima$lag, sep = "-")
 
     arima.coef <- as.numeric(z$arima$estimate)
@@ -67,14 +75,14 @@ read_est <- function(file){
   } else {
     variance.end <- length(est)
   }
-  
+
   # output
-  z$variance <- read.table(text = est[(variance.start + 2):variance.end], 
+  z$variance <- read.table(text = est[(variance.start + 2):variance.end],
                            stringsAsFactors = FALSE, sep = "\t")
-  
+
   z$coefficients <- c(reg.coef, arima.coef)
   z$se <- c(reg.se, arima.se)
-  
+
   z
 }
 
