@@ -72,26 +72,7 @@ x13_import <- function(iofile, x = NULL, na.action, out = FALSE) {
 
   # read .mdl file
 
-  mdl <- readLines(paste0(iofile, ".mdl"))
-
-  # Workaround: in the .mdl output, full regime changes are returned weiredly.
-  # E.g.
-  # variables=(
-  #  td/ for before 1955.Jan/
-  # )
-  is.r.change <- grepl("//?[ A-Za-z]", mdl)
-  rch0 <- mdl[is.r.change]
-  rch <- gsub("//[ A-Za-z].+ ", "//", rch0)
-  rch <- gsub("/[ A-Za-z].+ ", "/", rch0)
-  mdl[is.r.change] <- rch
-  z$model <- try(parse_spc(mdl), silent = TRUE)
-
-  is.r.change <- grepl("//?[ A-Za-z]", mdl)
-
-  # fails for very complicated models, but is needed only for static()
-  if (inherits(z$model, "try-error")){
-    z$model <- NULL
-  }
+  z$model <- read_mdl(iofile)
 
   # read .out file (will be returned only if out = TRUE)
   outtxt <-  readLines(outfile, encoding = "UTF-8")
